@@ -19,3 +19,5 @@ HOST = 'host'
 PORT = 'port'
 ADMIN_USER = 'admin_username'
 ADMIN_PASS = 'admin_password'
+DB_NAME = 'db_name'
+LAUNCH_TIMEOUT = 'launch_timeout_s'
